==> genshitjokes-2023.5.24.tar.gz: genshitjokes-2023.5.24/genshitjokes/3A之战/3A之战.md <==
# 3A之战

## 一.任天堂专区   Nintendo

### 1.PC玩的

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/PC塞尔达.jpg)

### 2.认父作子

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/认父作子.jpg)


### 3.塞尔达的认可  Zelda's approvement

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/塞尔达的认可.jpg)

### 4.起死回生  Bring the dead to life

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/起死回生.jpg)

### 5.版权在我   ©MIHOYO

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/版权在我.jpg)

### 6.小圈子与大市场   Small group vs giant market

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/小圈子与大市场.jpg)

### 7.Steam塞尔达156小时

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/Steam塞尔达156小时.jpg)

### 8.塞尔达联动原神 Combine

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/塞尔达联动原神.jpg)

### 9.提升高度

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/提升高度.jpg)

### 10.任天堂的最后一搏   Final Try

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/任天堂的最后一搏.jpg)

### 11.丘丘人   QQ Man

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/丘丘人.jpg)

### 12.跳槽   Jump Higher

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/跳槽.jpg)

### 13.青春版   Lite

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/青春版.jpg)

### 14.中关村在线   ZOL

塞尔达王国之泪不如原神 苦等四年328不如充原石

[官网](https://m.zol.com.cn/article/8177423.html)

[Microsoft新闻](https://www.msn.cn/zh-cn/games/other/%E5%A1%9E%E5%B0%94%E8%BE%BE%E7%8E%8B%E5%9B%BD%E4%B9%8B%E6%B3%AA%E4%B8%8D%E5%A6%82%E5%8E%9F%E7%A5%9E-%E8%8B%A6%E7%AD%89%E5%9B%9B%E5%B9%B4328%E4%B8%8D%E5%A6%82%E5%85%85%E5%8E%9F%E7%9F%B3/ar-AA1b4qwS?ocid=msedgdhp&pc=U531&cvid=50103c0e1a874f4591f912f957e3654b&ei=16)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/中关村在线.jpg)

## 二.索尼专区   SONY

### 1.移动设备   Mobile devices

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/移动设备.jpg)


## 三.Steam专区

### 1.Staem促销 Sales of Steam

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Staem促销.jpg)


## 四.SE专区   Square Enix

### 1.认真负责的尼尔   Nier is working hard

~~我永远单推A2大姐姐~~

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/NieR/认真负责的尼尔.jpg)

### 2.做成游戏就好了   Anime->Game

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/NieR/做成游戏就好了.jpg)

### 3.抄袭优菈

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/NieR/抄袭优菈.jpg)

## 五.微软专区

### 1.微软没有实力

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/微软没有实力.jpg)


## 六.R星专区   Rockstar

### 1.GTA奖  GTA Award

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Rockstar/GTA奖.jpg)

### 2.GTA地图的先驱  Pre

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Rockstar/GTA地图的先驱.jpg)

### 3.让你20年  Give You 20 Years

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Rockstar/让你20年.jpg)

## 七.卡普空专区  CAPCOM

### 1.怪猎冷门   Monster Hunter:Cold Door

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/CAPCOM/怪猎冷门.jpg)

### 2.卡普空荒野之息   Breath of the Wild

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/CAPCOM/卡普空荒野之息.jpg)

## 八.育碧专区

### 1.元素视野   Element View

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/元素视野.jpg)

## X.傲视群雄

### 1.三巨头的失利   Loss of three giants

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/三巨头的失利.jpg)

### 2.米氏对比法   Monkey's Comparation

1.原神可以坐椅子，只狼不能坐椅子，原神赢。  
2.原神可以在游戏中射箭，鬼泣不能在游戏中射箭，原神赢。  
3.原神是开放世界游戏，能自由探索，怪物猎人不是开放世界游戏，原神赢。  
4.原神可以打开翅膀在空中飞行，刺客信条不能打开翅膀空中飞行。原神赢。  
5.原神可以随时随地和怪物战斗，地平线系列只能开车不能和怪物战斗，原神赢。  
还有更多的例子我就不举了，总之我们可以得出结论，原神比大多数3a游戏都要优秀。

### 3.

无知时诋毁原神，懂事时理解原神，成熟时要成为原友！ 越了解原神就会把它当成在黑夜一望无际的大海上给迷途的船只指引的灯塔，在烈日炎炎的夏天吹来的一股风，在寒风刺骨的冬天里的燃起的篝火！  
原神为什么是神？在谈论这个问题之前，我想先说说其他游戏相较于原神究竟差在了哪里。  
Ⅰ.首先是犯下傲慢之罪的塞尔达  
通过17年ign最佳游戏的荣誉，就傲视游戏界，这种傲慢的态度注定走不长远，事实也是如此，靠着阴险的tx水军用抄袭言论一度击败了神之后一直在走下坡路，最终泯然众人。与之相比神就谦卑异常，爬山不能调视角，开宝箱全是垃圾，武器角色混一个池，这都是神留给凡人的慈悲，神不是不会，只是不想通过太完美的表现让其他游戏绝望所以故意不用，可笑有些人不理解神的良苦用心，竟然还用这些事来讥讽神，我劝你们好自为之。  
Ⅱ.犯下愤怒之罪的明日方舟  
因为隔壁崩三说了几句粥游的不好，就跟人家对线，甚至拉帮结伙网络暴力，这无疑违背了神在《新约》中的一句话：“我觉得玩家就是要能很好的控制自己的情绪吧。”于是，神降下了他的惩罚，粥游被逐出二次元，粥粥人在NGA被彻底干碎，四散逃窜，一蹶不振，彻底沦为丧家之犬。  
Ⅲ.犯下懒惰之罪的LOL手游  
以为自己顶着个大IP就了不起了，违背神旨自创“佛系内测法”，极为可笑。另外大家有所不知，其实早在LOL手游公布前，策划闭上眼睛做冥想的时候，其脑海中看见的画面，正是站在光芒之中的原神，当时神告诉他：“你只可到这里，不可越过。”然而，神的劝说不但没有让LOL手游策划迷途知返，竟然还敢伙同端游LOL正面挑战神的威严。于是，神降下了他的惩罚，《开天》被神收归，LOL手游申核过程艰难拖沓，上线时间遥遥无期，最终被消耗完热情的广大玩家所抛弃。  
Ⅳ.犯下妒忌之罪的幻塔  
屡次被神击败，但口服心不服的tx，暗中对神充满了妒忌，甚至胆敢当众说出“塞尔达120神庙全通，漫展我就不去了，怕认错展台”这种大逆不道的话。于是，tx费尽心机制造出的原神竞品幻塔在含金量最高的游戏软件taptap中被神正面轻松击溃。不过，念在幻塔玩家最终皈依了神的教下，并且践行神的意志，讨伐了屡次以下犯上的塞尔达后，神应许了幻塔中的一切。  
Ⅴ.犯下贪婪之罪的王者荣耀  
只是初出茅庐，王者荣耀就火爆全国，而这，自然是因为神的应允。神本来钦定其为自己在人间的代言人，在自己力量还未成熟时替代自己继续进行文化输出，为此甚至不惜亲自为王者荣耀铺路，史称“登神长阶”，将一切荣耀都归给王者，甚至应允他可以带走自己最爱的日本角色。但最后王者策划却被利益蒙蔽了双眼，不再以践行神的理想为自己的理想，也不再聆听神的教诲，甚至自以为荣光已经超越了神，竟允许玩家说出“我流水120国登顶，你呢”这种亵渎神威的言论，于是神降下了他的惩罚，派描点天使关飞飞下界，对王者皮肤的质量与销量造成了恶劣的影响，从此沦为过街老鼠。  
Ⅵ.犯下暴食之罪的摩尔庄园手游  
在大神子王者荣耀堕落之后，神开始寻找下一个代言人，这一次，他选中了二神子摩尔庄园手游，相较与神，摩尔庄园手游无疑是不完美的，他没有神足以让对手窒息的二次元老婆，也没有神深不见底的技术力，即没有神舍我其谁的文化输出，还没有神铁打不动的流水，更没有神那无懈可击的孝子。但是，神将自己最优秀的两个特点（开放世界，家园系统）暂时交给了他，并复刻了大神子的登神长阶，但由于王者荣耀的事故，神认为或许是自己给的压力过大才导致了大神子的堕落，于是这一次神选择了不买水军，减少二神子的心理负担。最终，二神子不负众望，以神之名成功夺得游戏排行榜首位。然而，夺榜后的摩尔庄园手游竟然冒大不讳将家园系统占为己有，更妄图染指神力！只是他错误地认为神的成功来源于烹饪系统，最终他也因此犯下了暴食之罪，让玩家进游戏就种菜，最终被愤怒的玩家所抛弃。  
Ⅶ.犯下色欲之罪的碧蓝航线  
2.0版本之后，神已经非常虚弱了，邪神mihoyo吧用黑洞不断吸纳神的精气，神已经无力再向摩尔庄园手游降下神罚，只有最忠实的信徒依旧在维护神的尊严而已。此刻已经决心隐退的神在最后时刻依然心系二次元界，于是他选中了第三位神子——碧蓝航线。作为三神子，碧蓝航线很好地维护了二次元的尊严，但在接连击溃两代堕落的神子后，碧蓝航线遭遇了大淫魔少女前线，被吸走了神赋予自己的力量，于是在与偶像大师的联动中，角色立绘拉胯，皮肤质量下跌，剧情被炎上，彻底身败名裂。  
“仁慈的米父，我已坠入看不见原神的国度，请原谅我，我的自负，刻着一道孤独”  
“中国不能没有原神，就像西方不能没有耶路撒冷”  
“神说，要有光，就有了原神”  
“那光是真光，照亮一切生在世上的人”  

### 4.感觉不如原神。。。画质   less than Genshin ... image quality

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/感觉画质不如原神.jpg)

### 5.里程碑  Milepost

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/里程碑.jpg)

==> genshitjokes-2023.5.26.tar.gz: genshitjokes-2023.5.26/genshitjokes/3A之战/3A之战.md <==
# 3A之战

## 一.任天堂专区   Nintendo

### 1.PC玩的

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/PC塞尔达.jpg)

### 2.认父作子

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/认父作子.jpg)


### 3.塞尔达的认可  Zelda's approvement

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/塞尔达的认可.jpg)

### 4.起死回生  Bring the dead to life

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/起死回生.jpg)

### 5.版权在我   ©MIHOYO

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/版权在我.jpg)

### 6.小圈子与大市场   Small group vs giant market

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/小圈子与大市场.jpg)

### 7.Steam塞尔达156小时

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/Steam塞尔达156小时.jpg)

### 8.塞尔达联动原神 Combine

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/塞尔达联动原神.jpg)

### 9.提升高度

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/提升高度.jpg)

### 10.任天堂的最后一搏   Final Try

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/任天堂的最后一搏.jpg)

### 11.丘丘人   QQ Man

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/丘丘人.jpg)

### 12.跳槽   Jump Higher

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/跳槽.jpg)

### 13.青春版   Lite

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/青春版.jpg)

### 14.中关村在线   ZOL

塞尔达王国之泪不如原神 苦等四年328不如充原石

[官网](https://m.zol.com.cn/article/8177423.html)

[Microsoft新闻](https://www.msn.cn/zh-cn/games/other/%E5%A1%9E%E5%B0%94%E8%BE%BE%E7%8E%8B%E5%9B%BD%E4%B9%8B%E6%B3%AA%E4%B8%8D%E5%A6%82%E5%8E%9F%E7%A5%9E-%E8%8B%A6%E7%AD%89%E5%9B%9B%E5%B9%B4328%E4%B8%8D%E5%A6%82%E5%85%85%E5%8E%9F%E7%9F%B3/ar-AA1b4qwS?ocid=msedgdhp&pc=U531&cvid=50103c0e1a874f4591f912f957e3654b&ei=16)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Nintendo/中关村在线.jpg)

## 二.索尼专区   SONY

### 1.移动设备   Mobile devices

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/移动设备.jpg)


## 三.Steam专区

### 1.Staem促销 Sales of Steam

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Staem促销.jpg)


## 四.SE专区   Square Enix

### 1.认真负责的尼尔   Nier is working hard

~~我永远单推A2大姐姐~~

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/NieR/认真负责的尼尔.jpg)

### 2.做成游戏就好了   Anime->Game

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/NieR/做成游戏就好了.jpg)

### 3.抄袭优菈

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/NieR/抄袭优菈.jpg)

## 五.微软专区

### 1.微软没有实力

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/微软没有实力.jpg)


## 六.R星专区   Rockstar

### 1.GTA奖  GTA Award

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Rockstar/GTA奖.jpg)

### 2.GTA地图的先驱  Pre

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Rockstar/GTA地图的先驱.jpg)

### 3.让你20年  Give You 20 Years

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Rockstar/让你20年.jpg)

## 七.卡普空专区  CAPCOM

### 1.怪猎冷门   Monster Hunter:Cold Door

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/CAPCOM/怪猎冷门.jpg)

### 2.卡普空荒野之息   Breath of the Wild

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/CAPCOM/卡普空荒野之息.jpg)

## 八.育碧专区   Ubisoft

### 1.元素视野   Element View

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/Ubisoft/元素视野.jpg)

## 九.波兰蠢驴专区   CDPR

### 1.超越巫师   Beyond Witcher

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/CDPR/超越巫师.jpg)

## X.傲视群雄

### 1.三巨头的失利   Loss of three giants

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/三巨头的失利.jpg)

### 2.米氏对比法   Monkey's Comparation

1.原神可以坐椅子，只狼不能坐椅子，原神赢。  
2.原神可以在游戏中射箭，鬼泣不能在游戏中射箭，原神赢。  
3.原神是开放世界游戏，能自由探索，怪物猎人不是开放世界游戏，原神赢。  
4.原神可以打开翅膀在空中飞行，刺客信条不能打开翅膀空中飞行。原神赢。  
5.原神可以随时随地和怪物战斗，地平线系列只能开车不能和怪物战斗，原神赢。  
还有更多的例子我就不举了，总之我们可以得出结论，原神比大多数3a游戏都要优秀。

### 3.

无知时诋毁原神，懂事时理解原神，成熟时要成为原友！ 越了解原神就会把它当成在黑夜一望无际的大海上给迷途的船只指引的灯塔，在烈日炎炎的夏天吹来的一股风，在寒风刺骨的冬天里的燃起的篝火！  
原神为什么是神？在谈论这个问题之前，我想先说说其他游戏相较于原神究竟差在了哪里。  
Ⅰ.首先是犯下傲慢之罪的塞尔达  
通过17年ign最佳游戏的荣誉，就傲视游戏界，这种傲慢的态度注定走不长远，事实也是如此，靠着阴险的tx水军用抄袭言论一度击败了神之后一直在走下坡路，最终泯然众人。与之相比神就谦卑异常，爬山不能调视角，开宝箱全是垃圾，武器角色混一个池，这都是神留给凡人的慈悲，神不是不会，只是不想通过太完美的表现让其他游戏绝望所以故意不用，可笑有些人不理解神的良苦用心，竟然还用这些事来讥讽神，我劝你们好自为之。  
Ⅱ.犯下愤怒之罪的明日方舟  
因为隔壁崩三说了几句粥游的不好，就跟人家对线，甚至拉帮结伙网络暴力，这无疑违背了神在《新约》中的一句话：“我觉得玩家就是要能很好的控制自己的情绪吧。”于是，神降下了他的惩罚，粥游被逐出二次元，粥粥人在NGA被彻底干碎，四散逃窜，一蹶不振，彻底沦为丧家之犬。  
Ⅲ.犯下懒惰之罪的LOL手游  
以为自己顶着个大IP就了不起了，违背神旨自创“佛系内测法”，极为可笑。另外大家有所不知，其实早在LOL手游公布前，策划闭上眼睛做冥想的时候，其脑海中看见的画面，正是站在光芒之中的原神，当时神告诉他：“你只可到这里，不可越过。”然而，神的劝说不但没有让LOL手游策划迷途知返，竟然还敢伙同端游LOL正面挑战神的威严。于是，神降下了他的惩罚，《开天》被神收归，LOL手游申核过程艰难拖沓，上线时间遥遥无期，最终被消耗完热情的广大玩家所抛弃。  
Ⅳ.犯下妒忌之罪的幻塔  
屡次被神击败，但口服心不服的tx，暗中对神充满了妒忌，甚至胆敢当众说出“塞尔达120神庙全通，漫展我就不去了，怕认错展台”这种大逆不道的话。于是，tx费尽心机制造出的原神竞品幻塔在含金量最高的游戏软件taptap中被神正面轻松击溃。不过，念在幻塔玩家最终皈依了神的教下，并且践行神的意志，讨伐了屡次以下犯上的塞尔达后，神应许了幻塔中的一切。  
Ⅴ.犯下贪婪之罪的王者荣耀  
只是初出茅庐，王者荣耀就火爆全国，而这，自然是因为神的应允。神本来钦定其为自己在人间的代言人，在自己力量还未成熟时替代自己继续进行文化输出，为此甚至不惜亲自为王者荣耀铺路，史称“登神长阶”，将一切荣耀都归给王者，甚至应允他可以带走自己最爱的日本角色。但最后王者策划却被利益蒙蔽了双眼，不再以践行神的理想为自己的理想，也不再聆听神的教诲，甚至自以为荣光已经超越了神，竟允许玩家说出“我流水120国登顶，你呢”这种亵渎神威的言论，于是神降下了他的惩罚，派描点天使关飞飞下界，对王者皮肤的质量与销量造成了恶劣的影响，从此沦为过街老鼠。  
Ⅵ.犯下暴食之罪的摩尔庄园手游  
在大神子王者荣耀堕落之后，神开始寻找下一个代言人，这一次，他选中了二神子摩尔庄园手游，相较与神，摩尔庄园手游无疑是不完美的，他没有神足以让对手窒息的二次元老婆，也没有神深不见底的技术力，即没有神舍我其谁的文化输出，还没有神铁打不动的流水，更没有神那无懈可击的孝子。但是，神将自己最优秀的两个特点（开放世界，家园系统）暂时交给了他，并复刻了大神子的登神长阶，但由于王者荣耀的事故，神认为或许是自己给的压力过大才导致了大神子的堕落，于是这一次神选择了不买水军，减少二神子的心理负担。最终，二神子不负众望，以神之名成功夺得游戏排行榜首位。然而，夺榜后的摩尔庄园手游竟然冒大不讳将家园系统占为己有，更妄图染指神力！只是他错误地认为神的成功来源于烹饪系统，最终他也因此犯下了暴食之罪，让玩家进游戏就种菜，最终被愤怒的玩家所抛弃。  
Ⅶ.犯下色欲之罪的碧蓝航线  
2.0版本之后，神已经非常虚弱了，邪神mihoyo吧用黑洞不断吸纳神的精气，神已经无力再向摩尔庄园手游降下神罚，只有最忠实的信徒依旧在维护神的尊严而已。此刻已经决心隐退的神在最后时刻依然心系二次元界，于是他选中了第三位神子——碧蓝航线。作为三神子，碧蓝航线很好地维护了二次元的尊严，但在接连击溃两代堕落的神子后，碧蓝航线遭遇了大淫魔少女前线，被吸走了神赋予自己的力量，于是在与偶像大师的联动中，角色立绘拉胯，皮肤质量下跌，剧情被炎上，彻底身败名裂。  
“仁慈的米父，我已坠入看不见原神的国度，请原谅我，我的自负，刻着一道孤独”  
“中国不能没有原神，就像西方不能没有耶路撒冷”  
“神说，要有光，就有了原神”  
“那光是真光，照亮一切生在世上的人”  

### 4.感觉不如原神。。。画质   less than Genshin ... image quality

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/感觉画质不如原神.jpg)

### 5.里程碑  Milepost

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/3A之战/里程碑.jpg)
